Aioinject is a [dependency injection](https://en.wikipedia.org/wiki/Dependency_injection)
and [service locator](https://en.wikipedia.org/wiki/Service_locator_pattern)
library, made to easily work with dependency injection using python type annotations.

## Installation
Install with pip or your favorite package manager:
```
pip install aioinject
```
## Example

```python
--8<-- "docs/code/example.py"
```
